@@ -1,28 +1,25 @@
-
-/*  $Header$
+/*  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
+ *  Copyright (c) 2008-2009 Robert Ancell
  *
- *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
- *           
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *           
- *  This program is distributed in the hope that it will be useful, but 
+ *
+ *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  *  General Public License for more details.
- *           
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <stdlib.h>
-#include <assert.h>
 #include <sys/types.h>
 #include <glib-object.h>
 
@@ -30,14 +27,10 @@
 #include "unittest.h"
 #include "get.h"
 #include "display.h"
-#include "functions.h"
 #include "ui.h"
-#include "mp.h"
 #include "register.h"
 #include "mp-equation.h"
 
-time_t time();
-
 /* Calctool variables and options. */
 static CalculatorVariables calc_state;
 CalculatorVariables *v;
@@ -53,22 +46,25 @@ static void
 solve(const char *equation)
 {
     MPEquationOptions options;
-    int error;
+    MPErrorCode error;
     MPNumber result;
     char result_str[MAXLINE];
-    
+
     memset(&options, 0, sizeof(options));
-    options.base = 10;
     options.wordlen = 32;
     options.angle_units = MP_DEGREES;
-    
-    error = mp_equation_parse(equation, &options, &result);
-    if(error != 0) {
-        fprintf(stderr, "Error %d\n", error);
+
+    error = mp_equation_parse(equation, &options, &result, NULL);
+    if(error == PARSER_ERR_MP) {
+        fprintf(stderr, "Error: %s\n", mp_get_error());
+        exit(1);
+    }
+    else if(error != 0) {
+        fprintf(stderr, "Error: %s\n", mp_error_code_to_string(error));
         exit(1);
     }
     else {
-        mp_cast_to_string(&result, v->base, 9, 1, result_str, MAXLINE);
+        mp_cast_to_string(&result, 10, 9, 1, result_str, MAXLINE);
         printf("%s\n", result_str);
         exit(0);
     }
@@ -94,7 +90,7 @@ usage(int show_gtk)
               "  --help-gtk                      Show GTK+ options"));
     fprintf(stderr,
             "\n\n");
-    
+
     if (show_gtk) {
         /* Translators: Description on gcalctool command-line GTK+ options displayed on command-line */
         fprintf(stderr,
@@ -109,7 +105,7 @@ usage(int show_gtk)
                 "\n\n");
     }
 
-    /* Translators: Description on gcalctool application options displayed on command-line */    
+    /* Translators: Description on gcalctool application options displayed on command-line */
     fprintf(stderr,
             _("Application Options:\n"
               "  -u, --unittest                  Perform unittests\n"
@@ -123,17 +119,17 @@ get_options(int argc, char *argv[])
 {
     int i;
     char *arg;
-   
+
     for (i = 1; i < argc; i++) {
         arg = argv[i];
 
-        if (strcmp(arg, "-v") == 0 || 
+        if (strcmp(arg, "-v") == 0 ||
                  strcmp(arg, "--version") == 0 ||
                  strcmp(arg, "-?") == 0) {
             version();
             exit(0);
         }
-        else if (strcmp(arg, "-h") == 0 || 
+        else if (strcmp(arg, "-h") == 0 ||
                  strcmp(arg, "--help") == 0) {
             usage(FALSE);
             exit(0);
@@ -172,41 +168,27 @@ get_options(int argc, char *argv[])
 static void
 init_state(void)
 {
-    int acc, i;
+    /* Translators: Digits localized for the given language */
+    const char *digit_values = _("0,1,2,3,4,5,6,7,8,9,A,B,C,D,E,F");
+    const char *default_digits[] = {"0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "A", "B", "C", "D", "E", "F"};
+    gchar **digits;
+    gboolean use_default_digits = FALSE;
+    int i;
 
-    acc              = MAX_DIGITS + 12;     /* MP internal accuracy. */
+    digits = g_strsplit(digit_values, ",", -1);
+    for (i = 0; i < 16; i++) {
+        if (use_default_digits || digits[i] == NULL) {
+            use_default_digits = TRUE;
+            v->digits[i] = strdup(default_digits[i]);
+        }
+        else
+            v->digits[i] = strdup(digits[i]);
+    }
+    g_strfreev(digits);
 
-    v->error         = FALSE;  /* No calculator error initially. */
     v->radix         = get_radix();    /* Locale specific radix string. */
     v->tsep          = get_tsep();     /* Locale specific thousands separator. */
     v->tsep_count    = get_tsep_count();
-    
-    if (get_int_resource(R_ACCURACY, &i))
-        v->accuracy = i;
-    else
-        v->accuracy = DEFAULT_ACCURACY;
-    if (v->accuracy < 0 || v->accuracy > MAXACC) {
-       /* Translators: A log message displayed when an invalid accuracy
-        is read from the configuration */
-       fprintf(stderr, _("%s: accuracy should be in the range 0-%d\n"), 
-               v->progname, MAXACC);
-       v->accuracy = DEFAULT_ACCURACY;
-    }
-
-    if (get_int_resource(R_BASE, &i))
-       v->base = i;
-    else
-       v->base = 10;
-
-    if (get_enumerated_resource(R_TRIG, Rtstr, &i))
-       v->ttype = (MPAngleUnit) i;
-    else
-       v->ttype = MP_DEGREES;
-
-    if (get_int_resource(R_WORDLEN, &i))
-       v->wordlen = i;
-    else
-       v->wordlen = 64;
 }
 
 
@@ -215,20 +197,20 @@ main(int argc, char **argv)
 {
     memset(&calc_state, 0, sizeof(calc_state));
     v = &calc_state;
-    
+
     g_type_init();
 
-    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+    bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 
     v->progname = g_path_get_basename(argv[0]);
-    
-    /* Seed random number generator. */   
+
+    /* Seed random number generator. */
     srand48((long) time((time_t *) 0));
-   
+
     resources_init();
-    
+
     init_state();
     register_init();
     display_init(&v->display);
@@ -238,6 +220,8 @@ main(int argc, char **argv)
 
     ui_load();
     ui_start();
-    
+
+    currency_free_resources();
+
     return(0);
 }
