@@ -61,7 +61,8 @@
      BOOLEAN_OPERATOR = 277,
      PERCENTAGE = 278,
      UNARY_MINUS = 279,
-     tINVERSE = 280
+     tINVERSE = 280,
+     tIN = 281
    };
 #endif
 /* Tokens.  */
@@ -88,6 +89,7 @@
 #define PERCENTAGE 278
 #define UNARY_MINUS 279
 #define tINVERSE 280
+#define tIN 281
 
 
 
@@ -97,7 +99,7 @@ typedef union YYSTYPE
 {
 
 /* Line 1676 of yacc.c  */
-#line 81 "./mp-equation-parser.y"
+#line 91 "./mp-equation-parser.y"
 
   MPNumber int_t;
   int integer;
@@ -106,7 +108,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 110 "mp-equation-parser.h"
+#line 112 "mp-equation-parser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
